@@ -2,8 +2,10 @@ from .cp2png import *
 from .cp2svg import *
 from .opx2png import *
 from .opx2svg import *
+from .opx2cp import *
 from .orh2png import *
 from .orh2svg import *
+from .orh2cp import *
 
 from .from_cp import from_cp, from_cp_str
 from .from_opx import from_opx
@@ -11,5 +13,6 @@ from .from_orh import from_orh
 
 from .to_png import to_png
 from .to_svg import to_svg
+from .to_cp import to_cp
 
 from .main import main
