@@ -7,6 +7,6 @@ def to_cp(cp: Cp) -> str:
     """
     cp_str = ''
     for line in cp.lines:
-        cp_str += line.type.value + " " + line.x1 + " " + line.y1 + " " + line.x2 + " " + line.y2 + "\n"
+        cp_str += "%d %f %f %f\n" % (line.type.value, line.x1, line.y1, line.x2, line.y2)
 
     return cp_str
